@@ -389,36 +389,36 @@ md_test.credits = [
 ]
 md_test.tags = []
 md_test.pages = [
-    {"Image": "0", "ImageHeight": "1280", "ImageSize": "195977", "ImageWidth": "800", "Type": "FrontCover"},
-    {"Image": "1", "ImageHeight": "2039", "ImageSize": "611993", "ImageWidth": "1327"},
-    {"Image": "2", "ImageHeight": "2039", "ImageSize": "783726", "ImageWidth": "1327"},
-    {"Image": "3", "ImageHeight": "2039", "ImageSize": "679584", "ImageWidth": "1327"},
-    {"Image": "4", "ImageHeight": "2039", "ImageSize": "788179", "ImageWidth": "1327"},
-    {"Image": "5", "ImageHeight": "2039", "ImageSize": "864433", "ImageWidth": "1327"},
-    {"Image": "6", "ImageHeight": "2039", "ImageSize": "765606", "ImageWidth": "1327"},
-    {"Image": "7", "ImageHeight": "2039", "ImageSize": "876427", "ImageWidth": "1327"},
-    {"Image": "8", "ImageHeight": "2039", "ImageSize": "852622", "ImageWidth": "1327"},
-    {"Image": "9", "ImageHeight": "2039", "ImageSize": "800205", "ImageWidth": "1327"},
-    {"Image": "10", "ImageHeight": "2039", "ImageSize": "746243", "ImageWidth": "1326"},
-    {"Image": "11", "ImageHeight": "2039", "ImageSize": "718062", "ImageWidth": "1327"},
-    {"Image": "12", "ImageHeight": "2039", "ImageSize": "532179", "ImageWidth": "1326"},
-    {"Image": "13", "ImageHeight": "2039", "ImageSize": "686708", "ImageWidth": "1327"},
-    {"Image": "14", "ImageHeight": "2039", "ImageSize": "641907", "ImageWidth": "1327"},
-    {"Image": "15", "ImageHeight": "2039", "ImageSize": "805388", "ImageWidth": "1327"},
-    {"Image": "16", "ImageHeight": "2039", "ImageSize": "668927", "ImageWidth": "1326"},
-    {"Image": "17", "ImageHeight": "2039", "ImageSize": "710605", "ImageWidth": "1327"},
-    {"Image": "18", "ImageHeight": "2039", "ImageSize": "761398", "ImageWidth": "1326"},
-    {"Image": "19", "ImageHeight": "2039", "ImageSize": "743807", "ImageWidth": "1327"},
-    {"Image": "20", "ImageHeight": "2039", "ImageSize": "552911", "ImageWidth": "1326"},
-    {"Image": "21", "ImageHeight": "2039", "ImageSize": "556827", "ImageWidth": "1327"},
-    {"Image": "22", "ImageHeight": "2039", "ImageSize": "675078", "ImageWidth": "1326"},
+    {"Image": 0, "ImageHeight": "1280", "ImageSize": "195977", "ImageWidth": "800", "Type": PageType.FrontCover},
+    {"Image": 1, "ImageHeight": "2039", "ImageSize": "611993", "ImageWidth": "1327"},
+    {"Image": 2, "ImageHeight": "2039", "ImageSize": "783726", "ImageWidth": "1327"},
+    {"Image": 3, "ImageHeight": "2039", "ImageSize": "679584", "ImageWidth": "1327"},
+    {"Image": 4, "ImageHeight": "2039", "ImageSize": "788179", "ImageWidth": "1327"},
+    {"Image": 5, "ImageHeight": "2039", "ImageSize": "864433", "ImageWidth": "1327"},
+    {"Image": 6, "ImageHeight": "2039", "ImageSize": "765606", "ImageWidth": "1327"},
+    {"Image": 7, "ImageHeight": "2039", "ImageSize": "876427", "ImageWidth": "1327"},
+    {"Image": 8, "ImageHeight": "2039", "ImageSize": "852622", "ImageWidth": "1327"},
+    {"Image": 9, "ImageHeight": "2039", "ImageSize": "800205", "ImageWidth": "1327"},
+    {"Image": 10, "ImageHeight": "2039", "ImageSize": "746243", "ImageWidth": "1326"},
+    {"Image": 11, "ImageHeight": "2039", "ImageSize": "718062", "ImageWidth": "1327"},
+    {"Image": 12, "ImageHeight": "2039", "ImageSize": "532179", "ImageWidth": "1326"},
+    {"Image": 13, "ImageHeight": "2039", "ImageSize": "686708", "ImageWidth": "1327"},
+    {"Image": 14, "ImageHeight": "2039", "ImageSize": "641907", "ImageWidth": "1327"},
+    {"Image": 15, "ImageHeight": "2039", "ImageSize": "805388", "ImageWidth": "1327"},
+    {"Image": 16, "ImageHeight": "2039", "ImageSize": "668927", "ImageWidth": "1326"},
+    {"Image": 17, "ImageHeight": "2039", "ImageSize": "710605", "ImageWidth": "1327"},
+    {"Image": 18, "ImageHeight": "2039", "ImageSize": "761398", "ImageWidth": "1326"},
+    {"Image": 19, "ImageHeight": "2039", "ImageSize": "743807", "ImageWidth": "1327"},
+    {"Image": 20, "ImageHeight": "2039", "ImageSize": "552911", "ImageWidth": "1326"},
+    {"Image": 21, "ImageHeight": "2039", "ImageSize": "556827", "ImageWidth": "1327"},
+    {"Image": 22, "ImageHeight": "2039", "ImageSize": "675078", "ImageWidth": "1326"},
     {
         "Bookmark": "Interview",
         "Image": "23",
         "ImageHeight": "2032",
         "ImageSize": "800965",
         "ImageWidth": "1338",
-        "Type": "Letters",
+        "Type": PageType.Letters,
     },
 ]
 md_test.price = None
