@@ -77,8 +77,8 @@ old_template_tooltip = """
 new_template_tooltip = """
 <pre>The template for the new filename. Uses python format strings https://docs.python.org/3/library/string.html#format-string-syntax
 Accepts the following variables:
-{isEmpty}       (boolean)
-{tagOrigin}     (string)
+{is_empty}       (boolean)
+{tag_origin}     (string)
 {series}        (string)
 {issue}     (string)
 {title}     (string)
@@ -86,42 +86,42 @@ Accepts the following variables:
 {month}     (integer)
 {year}      (integer)
 {day}       (integer)
-{issueCount}    (integer)
+{issue_count}    (integer)
 {volume}        (integer)
 {genre}     (string)
 {language}      (string)
 {comments}      (string)
-{volumeCount}   (integer)
-{criticalRating}    (string)
+{volume_count}   (integer)
+{critical_rating}    (string)
 {country}       (string)
-{alternateSeries}   (string)
-{alternateNumber}   (string)
-{alternateCount}    (integer)
+{alternate_series}   (string)
+{alternate_number}   (string)
+{alternate_count}    (integer)
 {imprint}       (string)
 {notes}     (string)
-{webLink}       (string)
+{web_link}       (string)
 {format}        (string)
 {manga}     (string)
-{blackAndWhite} (boolean)
-{pageCount}     (integer)
-{maturityRating}    (string)
-{storyArc}      (string)
-{seriesGroup}   (string)
-{scanInfo}      (string)
+{black_and_white} (boolean)
+{page_count}     (integer)
+{maturity_rating}    (string)
+{story_arc}      (string)
+{series_group}   (string)
+{scan_info}      (string)
 {characters}    (string)
 {teams}     (string)
 {locations}     (string)
-{credits}       (list of dict({&apos;role&apos;: &apos;str&apos;, &apos;person&apos;: &apos;str&apos;, &apos;primary&apos;: boolean}))
+{credits}       (list of dict({&apos;role&apos;: string, &apos;person&apos;: string, &apos;primary&apos;: boolean}))
 {tags}      (list of str)
-{pages}     (list of dict({&apos;Image&apos;: &apos;str(int)&apos;, &apos;Type&apos;: &apos;str&apos;}))
+{pages}     (list of dict({&apos;Image&apos;: string(int), &apos;Type&apos;: string}))
 
 CoMet-only items:
 {price}     (float)
-{isVersionOf}   (string)
+{is_version_of}   (string)
 {rights}        (string)
 {identifier}    (string)
-{lastMark}  (string)
-{coverImage}    (string)
+{last_mark}  (string)
+{cover_image}    (string)
 
 Examples:
 
