@@ -1,45 +1,50 @@
 """Some utilities for the GUI"""
 
-#import StringIO
-
-#from PIL import Image
+import io
+import logging
+import traceback
 
 from comictaggerlib.settings import ComicTaggerSettings
 
+logger = logging.getLogger(__name__)
 
 try:
-    from PyQt5 import QtGui
+    from PyQt5 import QtGui, QtWidgets
+
     qt_available = True
 except ImportError:
     qt_available = False
 
 if qt_available:
+    try:
+        from PIL import Image, ImageQt
 
-    def reduceWidgetFontSize(widget, delta=2):
+        pil_available = True
+    except ImportError:
+        pil_available = False
+
+    def reduce_widget_font_size(widget, delta=2):
         f = widget.font()
         if f.pointSize() > 10:
             f.setPointSize(f.pointSize() - delta)
         widget.setFont(f)
 
-    def centerWindowOnScreen(window):
+    def center_window_on_screen(window):
         """Center the window on screen.
 
         This implementation will handle the window
         being resized or the screen resolution changing.
         """
         # Get the current screens' dimensions...
-        screen = QtGui.QDesktopWidget().screenGeometry()
-        # ... and get this windows' dimensions
-        mysize = window.geometry()
-        # The horizontal position is calculated as screen width - window width
-        # / 2
-        hpos = (screen.width() - window.width()) / 2
+        screen = QtGui.QGuiApplication.primaryScreen().geometry()
+        # The horizontal position is calculated as (screen width - window width) / 2
+        hpos = int((screen.width() - window.width()) / 2)
         # And vertical position the same, but with the height dimensions
-        vpos = (screen.height() - window.height()) / 2
+        vpos = int((screen.height() - window.height()) / 2)
         # And the move call repositions the window
         window.move(hpos, vpos)
 
-    def centerWindowOnParent(window):
+    def center_window_on_parent(window):
 
         top_level = window
         while top_level.parent() is not None:
@@ -48,42 +53,32 @@ if qt_available:
         # Get the current screens' dimensions...
         main_window_size = top_level.geometry()
         # ... and get this windows' dimensions
-        mysize = window.geometry()
-        # The horizontal position is calculated as screen width - window width
-        # /2
+        # The horizontal position is calculated as (screen width - window width) / 2
         hpos = int((main_window_size.width() - window.width()) / 2)
         # And vertical position the same, but with the height dimensions
         vpos = int((main_window_size.height() - window.height()) / 2)
         # And the move call repositions the window
-        window.move(
-            hpos +
-            main_window_size.left(),
-            vpos +
-            main_window_size.top())
+        window.move(hpos + main_window_size.left(), vpos + main_window_size.top())
 
-    try:
-        from PIL import Image
-        import io
-        pil_available = True
-    except ImportError:
-        pil_available = False
-
-    def getQImageFromData(image_data):
+    def get_qimage_from_data(image_data):
         img = QtGui.QImage()
         success = img.loadFromData(image_data)
         if not success:
             try:
                 if pil_available:
-                    #  Qt doesn't understand the format, but maybe PIL does
-                    # so try to convert the image data to uncompressed tiff
-                    # format
-                    im = Image.open(io.StringIO(image_data))
-                    output = io.StringIO()
-                    im.save(output, format="PNG")
-                    success = img.loadFromData(output.getvalue())
-            except Exception as e:
+                    # Qt doesn't understand the format, but maybe PIL does
+                    img = ImageQt.ImageQt(Image.open(io.BytesIO(image_data)))
+                    success = True
+            except Exception:
                 pass
         # if still nothing, go with default image
         if not success:
-            img.load(ComicTaggerSettings.getGraphic('nocover.png'))
+            img.load(ComicTaggerSettings.get_graphic("nocover.png"))
         return img
+
+    def qt_error(msg: str, e: Exception = None):
+        trace = ""
+        if e:
+            trace = "\n".join(traceback.format_exception(type(e), e, e.__traceback__))
+
+        QtWidgets.QMessageBox.critical(QtWidgets.QMainWindow(), "Error", msg + trace)
